@@ -104,6 +104,7 @@ class BeaconAPI(object):
         "Ensure key / host are configured"
         if self.host is None:
             if 'BEACON_KEY' in os.environ:
+                self._debug("+ BEACON_KEY set, using environment key")
                 self.key = os.environ['BEACON_KEY']
                 self.host = os.environ.get('BEACON_HOST') or 'v2.decipherinc.com'
                 if not self.host.startswith('http'):
@@ -124,6 +125,7 @@ class BeaconAPI(object):
                 username = pwd.getpwuid(os.getuid()).pw_name
                 self.key = 'local %s %s' % (username, hmac.new(ekey, username).hexdigest())
             else:
+                self._debug("+ Environment unset, using INI file section %s" % self.section)
                 try:
                     self.key, self.host, _ = self._load(self.section)
                 except KeyError:
@@ -162,7 +164,7 @@ class BeaconAPI(object):
         try:
             r = requests.request(action, url, verify=True, headers=headers, **kw)
         except requests.ConnectionError, e:
-            raise BeaconAPIException(code=500, message="Could not connect to server: %s" % e)
+            raise BeaconAPIException(code=500, message="Could not connect to server (%s): %s" % (url, e))
         self._debug('<< %s %s' % (r.status_code, r.reason))
         if 'x-typehint' in r.headers:
             self._debug('< x-typehint: %s' % r.headers['x-typehint'])
